@@ -10,7 +10,7 @@ use Cwd;
 use File::Path;
 our @ISA = qw( Module::Build );
 
-our $VERSION ='0.50';
+our $VERSION ='0.61';
 
 sub process_xs_files {
 	my $self = shift;
@@ -38,19 +38,16 @@ sub hipi_run_command {
 sub ACTION_clean {
     my $self = shift;
     $self->SUPER::ACTION_clean;
-    File::Path::remove_tree('BCM2835/buildlib') if -d 'BCM2835/buildlib';
-    unlink('mylib/lib/libbcm2835Static.a');
 }
 
 sub ACTION_build {
     my $self = shift;
     $self->SUPER::ACTION_build;
-    $self->hipi_build_bcm2835_library;
     $self->hipi_build_xs;
-    $self->hipi_build_data;
     $self->log_info(qq(Build Complete\n));
 }
 
+
 # Build test action invokes build first
 sub ACTION_test {
 	my $self = shift;
@@ -65,81 +62,11 @@ sub ACTION_install {
 	$self->SUPER::ACTION_install;
 }
 
-sub hipi_build_wiring_library {
-    my $self = shift;
-    
-    $self->log_info(qq(Building wiringPi library\n));
-    mkdir( 'mylib/lib', 0777 ) if !-d 'mylib/lib';
-    my $tgtlib = 'mylib/lib/libwiringPiStatic.a';
-	my $tgtlibDev = 'mylib/lib/libwiringPiDevStatic.a';
-    return if( $self->up_to_date( 'Build', $tgtlib ) && $self->up_to_date( 'Build', $tgtlibDev ) );
-    
-    my $gcc = $Config{cc};
-    $gcc = 'gcc' if $gcc eq 'cc';
-    my $gxx = $gcc;
-    $gxx =~ s/^gcc/g\+\+/;
-    my $gld = $Config{ld};
-    
-    my @cmd = (
-		qq(make static CC=$gcc CXX=$gxx LD=$gld),
-	);
-	chdir('Wiring/src/wiringPi');
-	$self->hipi_run_command( \@cmd );
-	chdir('../../../');
-	chdir('Wiring/src/devLib');
-	$self->hipi_run_command( \@cmd );
-    chdir('../../../');
-    # copy the lib
-    my $srclib = 'Wiring/src/wiringPi/libwiringPi.a';
-	my $srclibDev = 'Wiring/src/devLib/libwiringPiDev.a';
-    File::Copy::copy( $srclib, $tgtlib );
-	File::Copy::copy( $srclibDev, $tgtlibDev );
-}
-
-sub hipi_build_bcm2835_library {
-    my $self = shift;
-    
-    $self->log_info(qq(Building bcm2835 library\n));
-    mkdir( 'mylib/lib', 0777 ) if !-d 'mylib/lib';
-    my $tgtlib = 'mylib/lib/libbcm2835Static.a';
-    
-    return if $self->up_to_date( [ 'Build', 'BCM2835/src/src/bcm2835.c', 'BCM2835/src/src/bcm2835.h' ], [ $tgtlib ] );
-     
-    my $gcc = $Config{cc};
-    $gcc = 'gcc' if $gcc eq 'cc';
-    my $gxx = $gcc;
-    $gxx =~ s/^gcc/g\+\+/;
-    my $gld = $Config{ld};
-    
-    chdir('BCM2835');
-    my $buildlibdir = Cwd::abs_path( getcwd() );
-    die 'Failed to determine working directory' unless $buildlibdir && $buildlibdir =~ /\/BCM2835/;
-    
-    $buildlibdir .= '/buildlib';
-    mkdir( $buildlibdir, 0777 );
-        
-    chdir('buildlib');
-    my $quiet = ( $self->verbose ) ? '' : '--quiet ';
-    my @cmd = (
-		qq(sh ../src/configure $quiet--prefix=$buildlibdir CC=$gcc CXX=$gxx LD=$gld),
-	);
-
-	$self->hipi_run_command( \@cmd );
-    @cmd = (
-		qq(make $quiet),
-	);
-    $self->hipi_run_command( \@cmd );
-    
-    chdir('../../');
-    
-    # copy the lib
-    my $srclib = 'BCM2835/buildlib/src/libbcm2835.a';
-    File::Copy::copy( $srclib, $tgtlib );
-}
-
 sub hipi_build_xs {
     my $self = shift;
     
+    return if $^O !~ /linux/i;
+    
     $self->log_info(qq(Building XS Files\n));
     
     my @modules = (
@@ -147,8 +74,7 @@ sub hipi_build_xs {
         { name => 'Exec', version => $VERSION, autopath => 'HiPi/Utils/Exec', libs => '-lz' },
         { name => 'I2C',  version => $VERSION, autopath => 'HiPi/Device/I2C', libs => '' },
         { name => 'SPI',  version => $VERSION, autopath => 'HiPi/Device/SPI', libs => '' },
-        { name => 'BCM2835', version => $VERSION, autopath => 'HiPi/BCM2835', libs => '-Lmylib/lib -lbcm2835Static' },
-        { name => 'Wiring',  version => $VERSION, autopath => 'HiPi/Wiring',  libs => '-lwiringPi -lwiringPiDev' },
+        { name => 'GPIO', version => $VERSION, autopath => 'HiPi/GPIO', libs => '' },
     );
     
     #----------------------------------------------
