@@ -1,30 +1,24 @@
 #########################################################################################
-# Package       HiPi::Device::GPIO
-# Description:  System GPIO Device
-# Created       Wed Feb 20 02:40:29 2013
-# SVN Id        $Id: GPIO.pm 98 2016-04-06 04:32:02Z Mark Dootson $
-# Copyright:    Copyright (c) 2013 Mark Dootson
-# Licence:      This work is free software; you can redistribute it and/or modify it 
-#               under the terms of the GNU General Public License as published by the 
-#               Free Software Foundation; either version 3 of the License, or any later 
-#               version.
+# Package        HiPi::Device::GPIO
+# Description:   Wrapper for GPIO
+# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# License      : This is free software; you can redistribute it and/or modify it under
+#                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
 
 package HiPi::Device::GPIO;
 
 #########################################################################################
-use 5.14.0;
 use strict;
 use warnings;
-use HiPi;
 use parent qw( HiPi::Device );
-use HiPi::Constant qw( :raspberry );
 use Carp;
 use HiPi::Device::GPIO::Pin;
 use Time::HiRes;
-use HiPi::Utils qw( :all );
 
-our $VERSION ='0.50';
+our $VERSION ='0.61';
+
+my $sysroot = '/sys/class/gpio';
 
 use constant {
     DEV_GPIO_PIN_STATUS_NONE         => 0x00,
@@ -60,11 +54,11 @@ sub get_pin {
 
 sub export_pin {
     my( $self, $pinno, $gname ) = @_;
-    my $pinroot = '/sys/class/gpio/gpio' . $pinno;
+    my $pinroot = qq(${sysroot}/gpio${pinno});
     # export the pin
     
     if( !-d $pinroot ) {
-        HiPi::system_sudo_shell(qq(/bin/echo $pinno > /sys/class/gpio/export)) and croak qq(failed to export pin $pinno : $!);
+        system(qq(/bin/echo $pinno > ${sysroot}/export)) and croak qq(failed to export pin $pinno : $!);
     }
     
     {
@@ -83,30 +77,23 @@ sub export_pin {
         }
     }
     
-    if( $gname && !uses_device_tree ) {
-        # change exported permissions
-        for my $fname ( qw(value edge direction active_low) ) {
-            my $file = qq($pinroot/$fname);
-            HiPi::system_sudo( qq(chmod 0664 $pinroot/$fname) ) and croak qq(failed to change permissions for pin $pinno : $!);
-            HiPi::system_sudo( qq(chown root:$gname $pinroot/$fname) ) and croak qq(failed to change group for pin $pinno : $!);
-        }
-    }
-    
     $self->get_pin( $pinno );
 }
 
 sub unexport_pin {
     my( $self, $pinno ) = @_;
-    my $pinroot = '/sys/class/gpio/gpio' . $pinno;
+    my $pinroot = qq(${sysroot}/gpio${pinno});
     return if !-d $pinroot;
     # unexport the pin
-    HiPi::system_sudo_shell( qq(/bin/echo $pinno > /sys/class/gpio/unexport) ) and croak qq(failed to unexport pin $pinno : $!);
+    system( qq(/bin/echo $pinno > ${sysroot}/unexport) ) and croak qq(failed to unexport pin $pinno : $!);
 }
 
 sub pin_status {
     my($self, $pinno) = @_;
-    my $pinroot = '/sys/class/gpio/gpio' . $pinno;
+    my $pinroot = qq(${sysroot}/gpio${pinno});
     return (-d $pinroot ) ? DEV_GPIO_PIN_STATUS_EXPORTED : DEV_GPIO_PIN_STATUS_NONE;    
 }
 
 1;
+
+__END__
