@@ -1,28 +1,25 @@
 #########################################################################################
-# Package       HiPi::Device::GPIO::Pin
-# Description:  Pin
-# Created       Wed Feb 20 04:37:38 2013
-# SVN Id        $Id: Pin.pm 104 2016-04-17 17:51:37Z Mark Dootson $
-# Copyright:    Copyright (c) 2013 Mark Dootson
-# Licence:      This work is free software; you can redistribute it and/or modify it 
-#               under the terms of the GNU General Public License as published by the 
-#               Free Software Foundation; either version 3 of the License, or any later 
-#               version.
+# Package        HiPi::Device::GPIO::Pin
+# Description:   Pin
+# Created        Wed Feb 20 04:37:38 2013
+# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# License      : This is free software; you can redistribute it and/or modify it under
+#                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
 
 package HiPi::Device::GPIO::Pin;
 
 #########################################################################################
-use 5.14.0;
 use strict;
 use warnings;
 use parent qw( HiPi::Pin );
 use Carp;
 use Fcntl;
-use HiPi::Constant qw( :raspberry );
-use HiPi;
+use HiPi qw( :rpi );
 
-our $VERSION ='0.50';
+our $VERSION ='0.61';
+
+my $sysroot = '/sys/class/gpio';
 
 __PACKAGE__->create_accessors( qw( pinroot valfh ) );
 
@@ -30,7 +27,7 @@ sub _open {
     my ($class, %params) = @_;
     defined($params{pinid}) or croak q(pinid not defined in parameters);
     
-    my $pinroot = qq(/sys/class/gpio/gpio$params{pinid});
+    my $pinroot = qq(${sysroot}/gpio$params{pinid});
     croak qq(pin $params{pinid} is not exported) if !-d $pinroot;
     
     my $valfile = qq($pinroot/value);
@@ -78,20 +75,20 @@ sub _do_getmode {
     my $fh = _open_file( $self->pinroot . '/direction' );
     my $result = _read_fh_bytes( $fh, 16);
     close($fh);
-    return ( $result eq 'out' ) ? RPI_PINMODE_OUTP : RPI_PINMODE_INPT;
+    return ( $result eq 'out' ) ? RPI_MODE_OUTPUT : RPI_MODE_INPUT;
 }
 
 sub _do_setmode {
     my ($self, $newmode) = @_;
     my $fh = _open_file( $self->pinroot . '/direction' );
-    if( ($newmode == RPI_PINMODE_OUTP) || ($newmode eq 'out') )  {
+    if( ($newmode == RPI_MODE_OUTPUT) || ($newmode eq 'out') )  {
         _write_fh($fh, 'out');
         close($fh);
-        return RPI_PINMODE_OUTP;
+        return RPI_MODE_OUTPUT;
     } else {
         _write_fh($fh, 'in');
         close($fh);
-        return RPI_PINMODE_INPT;
+        return RPI_MODE_INPUT;
     }
 }
 
@@ -154,9 +151,10 @@ sub _do_setpud {
         croak(qq(Incorrect PUD setting $pudval));
     }
     
-    my $pinid = $self->pinid;
-    HiPi::system_sudo(qq(raspi-gpio set $pinid $pudchars)) and croak qq(failed to set pud resistor for $pinid : $!);
-    return 1;
+    require HiPi::GPIO;
+    
+    my $hipigpio = HiPi::GPIO->new;
+    $hipigpio->set_pin_pud($self->pinid, $pudval);
 }
 
 
