@@ -1,13 +1,10 @@
 #########################################################################################
-# Package       HiPi::Device::I2C
-# Description:  Wrapper for I2C communucation
-# Created       Fri Nov 23 13:55:49 2012
-# SVN Id        $Id: I2C.pm 98 2016-04-06 04:32:02Z Mark Dootson $
-# Copyright:    Copyright (c) 2012 Mark Dootson
-# Licence:      This work is free software; you can redistribute it and/or modify it 
-#               under the terms of the GNU General Public License as published by the 
-#               Free Software Foundation; either version 3 of the License, or any later 
-#               version.
+# Package        HiPi::Device::I2C
+# Description:   Wrapper for I2C communucation
+# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# License      : This is free software; you can redistribute it and/or modify it under
+#                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
 
 package HiPi::Device::I2C;
@@ -16,133 +13,63 @@ package HiPi::Device::I2C;
 
 use strict;
 use warnings;
-use HiPi;
 use parent qw( HiPi::Device );
+use HiPi qw( :i2c :rpi );
+use HiPi::RaspberryPi;
 use IO::File;
 use Fcntl;
 use XSLoader;
 use Carp;
 use Time::HiRes qw( usleep );
-use HiPi::Constant qw( :raspberry :i2c_readmode);
-use HiPi::Utils qw( is_raspberry );
 use Try::Tiny;
 
-our $VERSION ='0.50';
+our $VERSION ='0.61';
 
-__PACKAGE__->create_accessors( qw ( fh fno address i2cbuffer busmode readmode ) );
+__PACKAGE__->create_accessors( qw ( fh fno address busmode readmode ) );
 
-XSLoader::load('HiPi::Device::I2C', $VERSION) if is_raspberry;
+XSLoader::load('HiPi::Device::I2C', $VERSION) if HiPi::is_raspberry_pi();
 
-our @EXPORT_OK = ();
-our %EXPORT_TAGS = ( all => \@EXPORT_OK );
+my $combined_param_path = '/sys/module/i2c_bcm2708/parameters/combined';
+my $baudrate_param_path = '/sys/module/i2c_bcm2708/parameters/baudrate';
 
-sub _register_exported_constants {
-    my( $tag, @constants ) = @_;
-    $EXPORT_TAGS{$tag} = \@constants;
-    push( @EXPORT_OK, @constants);
+sub get_required_module_options {
+    my $moduleoptions = [
+        [ qw( i2c_bcm2708 i2c_dev ) ],
+    ];
+    return $moduleoptions;
 }
 
-use constant {
-    I2C_RETRIES     => 0x0701,
-    I2C_TIMEOUT     => 0x0702,
-    I2C_SLAVE       => 0x0703,
-    I2C_TENBIT      => 0x0704,
-    I2C_FUNCS       => 0x0705,
-    I2C_SLAVE_FORCE => 0x0706,
-    I2C_RDWR        => 0x0707,
-    I2C_PEC         => 0x0708,
-    I2C_SMBUS       => 0x0720,
-    
-    I2C_DEFAULT_BAUD => 100000,
-    
-    I2C_M_TEN          => 0x0010,
-    I2C_M_RD		   => 0x0001,
-    I2C_M_NOSTART	   => 0x4000,
-    I2C_M_REV_DIR_ADDR => 0x2000,
-    I2C_M_IGNORE_NAK   => 0x1000,
-    I2C_M_NO_RD_ACK	   => 0x0800,
-    I2C_M_RECV_LEN	   => 0x0400,
-
-};
-
-_register_exported_constants qw(
-    ioctl
-    I2C_RETRIES
-    I2C_TIMEOUT
-    I2C_SLAVE
-    I2C_SLAVE_FORCE
-    I2C_TENBIT
-    I2C_FUNCS
-    I2C_RDWR
-    I2C_PEC
-    I2C_SMBUS
-    I2C_DEFAULT_BAUD
-    
-    I2C_M_TEN 
-    I2C_M_RD
-    I2C_M_NOSTART
-    I2C_M_REV_DIR_ADDR
-    I2C_M_IGNORE_NAK 
-    I2C_M_NO_RD_ACK	
-    I2C_M_RECV_LEN
-    
-);
-
-our @_moduleinfo = (
-    { name => 'i2c_bcm2708', params => {}, },
-    { name => 'i2c_dev',     params => {}, },
-);
-
-my $_module_param_defaults = {
-    i2c_bcm2708 => { baudrate => 100000, combined => 'N' },
-    i2c_dev => {},
-};
-
-sub get_module_info {
-    return @_moduleinfo;
-}
-
-{
-    my $discard = __PACKAGE__->get_baudrate();
-    $discard = __PACKAGE__->get_combined();
+sub get_device_list {
+    # get the devicelist
+    opendir my $dh, '/dev' or croak qq(Failed to open dev : $!);
+    my @i2cdevs = grep { $_ =~ /^i2c-\d+$/ } readdir $dh;
+    closedir($dh);
+    for (my $i = 0; $i < @i2cdevs; $i++) {
+        $i2cdevs[$i] = '/dev/' . $i2cdevs[$i];
+    }
+    return @i2cdevs;
 }
 
 sub get_baudrate {
     my ($class) = @_;
-    my $baudrate = HiPi::qx_sudo_shell('/bin/cat /sys/module/i2c_bcm2708/parameters/baudrate 2>&1');
+    my $baudrate = qx(/bin/cat $baudrate_param_path);
     if($?) {
-        $_moduleinfo[0]->{params}->{baudrate} = $_module_param_defaults->{i2c_bcm2708}->{baudrate};
-        return $_moduleinfo[0]->{params}->{baudrate};
+        carp q(Unable to determine baudrate);
+        return 0;
     }
     chomp($baudrate);
-    $_moduleinfo[0]->{params}->{baudrate} = $baudrate;
     return $baudrate;
 }
 
-sub set_baudrate {
-    my ($class, $newrate) = @_;
-    $newrate ||= 3816;
-    $newrate = 3816 if $newrate < 3816;
-    $_moduleinfo[0]->{params}->{baudrate} = $newrate;
-    
-    # baudrate requires module reload
-    
-    $class->load_modules(1);
-}
 
 sub get_combined {
-    my ($class, $force) = @_;
-    $force ||= 0;
-    if (defined($_moduleinfo[0]->{params}->{combined}) && !$force ) {
-        return $_moduleinfo[0]->{params}->{combined};
-    }
-    my $combined = HiPi::qx_sudo_shell('/bin/cat /sys/module/i2c_bcm2708/parameters/combined 2>&1');
+    my ($class) = @_;
+    my $combined = qx(/bin/cat $combined_param_path);
     if($?) {
-         $_moduleinfo[0]->{params}->{combined} = $_module_param_defaults->{i2c_bcm2708}->{combined};
-        return $_moduleinfo[0]->{params}->{combined};
+        carp q(Unable to determine combined setting);
+        return 'N';
     }
     chomp($combined);
-    $_moduleinfo[0]->{params}->{combined} = $combined;
     return $combined;
 }
 
@@ -151,31 +78,20 @@ sub set_combined {
     $newval //= 'N';
     $newval = uc($newval);
     croak('Usage HiPi::Device::I2C->set_combined( "Y|N" )') unless ( $newval =~ /^Y|N$/ );
-    $_moduleinfo[0]->{params}->{combined} = $newval;
-    HiPi::qx_sudo_shell(qq(/bin/echo $newval > /sys/module/i2c_bcm2708/parameters/combined));
-}
-
-sub get_device_list {
-    # get the devicelist
-    opendir my $dh, '/dev' or croak qq(Failed to open dev : $!);
-    my @i2cdevs = grep { $_ =~ /^i2c-\d+$/ } readdir $dh;
-    closedir($dh);
-    
-    for (my $i = 0; $i < @i2cdevs; $i++) {
-        $i2cdevs[$i] = '/dev/' . $i2cdevs[$i];
-    }
-    return @i2cdevs;
+    qx(/bin/echo $newval > $combined_param_path);
+    return $newval;
 }
 
 sub new {
     my ($class, %userparams) = @_;
     
+    my $pi = HiPi::RaspberryPi->new();
+    
     my %params = (
-        devicename   => ( RPI_BOARD_REVISION == 1 ) ? '/dev/i2c-0' : '/dev/i2c-1',
+        devicename   => ( $pi->board_type == RPI_BOARD_TYPE_1 ) ? '/dev/i2c-0' : '/dev/i2c-1',
         address      => 0,
         fh           => undef,
         fno          => undef,
-        i2cbuffer    => [],
         busmode      => 'smbus',
         readmode     => I2C_READMODE_SYSTEM,
     );
@@ -183,12 +99,7 @@ sub new {
     foreach my $key (sort keys(%userparams)) {
         $params{$key} = $userparams{$key};
     }
-    
-    # if we are going to be writing module params we need permissions
-    if ( ($params{readmode} == I2C_READMODE_REPEATED_START) || ($params{readmode} == I2C_READMODE_START_STOP ) ) {
-        HiPi::use_sudo(1);
-    }
-    
+        
     my $fh = IO::File->new( $params{devicename}, O_RDWR, 0 ) or croak qq(open error on $params{devicename}: $!\n);
     
     $params{fh}  = $fh;
@@ -197,7 +108,7 @@ sub new {
     my $self = $class->SUPER::new(%params);
     
     # select address if id provided
-    $self->_do_select_address( $self->address ) if $self->address;
+    $self->select_address( $self->address ) if $self->address;
 
     return $self;
 }
@@ -215,19 +126,17 @@ sub close {
 
 sub select_address {
     my ($self, $address) = @_;
-    if( $address != $self->address ) {
-        $self->_do_select_address($address);
-    }
-    return $self->address;
+    $self->address( $address );
+    return $self->reset_ioctl;
 }
 
-sub _do_select_address {
-    my ($self, $address) = @_;
-    if( $self->ioctl( I2C_SLAVE, $address + 0 ) ) {
-        $self->address( $address );
-    } else {
-        croak(qq(Failed to activate address $address : $!));
+sub reset_ioctl {
+    my $self = shift;
+    my $result = -1;
+    if( $self->address ) {
+        $result = $self->ioctl( I2C_SLAVE, $self->address + 0 );
     }
+    return $result;
 }
 
 sub ioctl {
@@ -235,6 +144,21 @@ sub ioctl {
     $self->fh->ioctl( $ioctlconst, $data );
 }
 
+sub scan_bus {
+    my( $self, $mode, $start, $end) = @_;   
+    $mode //= I2C_SCANMODE_AUTO;
+    $start //= 0x03;
+    $end //= 0x77;
+    $start = 0x03 if $start < 0x03;
+    $end = 0x77 if $end > 0x77;
+    my @results = i2c_scan_bus($self->fno, $mode, $start, $end);
+    
+    # need to reset the ioctl address 
+    $self->reset_ioctl;
+    
+    return @results;
+}
+
 #-------------------------------------------
 # Methods that honour busmode (smbus or i2c)
 #-------------------------------------------
@@ -323,10 +247,6 @@ sub bus_write_bits {
     $self->bus_write($register, @bytes);
 }
 
-#-------------------------------------------
-# HiPi::BCM2835 IC2 compatibility
-#-------------------------------------------
-
 sub delay {
     my($class, $millis) = @_;
     usleep( $millis * 1000);
