@@ -1,13 +1,9 @@
 #########################################################################################
-# Package       HiPi::Device::OneWire
-# Description:  One Wire Device
-# Created       Sun Feb 10 02:31:12 2013
-# SVN Id        $Id: OneWire.pm 3 2015-03-12 01:07:32Z Mark Dootson $
-# Copyright:    Copyright (c) 2013 Mark Dootson
-# Licence:      This work is free software; you can redistribute it and/or modify it 
-#               under the terms of the GNU General Public License as published by the 
-#               Free Software Foundation; either version 3 of the License, or any later 
-#               version.
+# Package        HiPi::Device::OneWire
+# Description  : 1-Wire Device
+# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# License      : This is free software; you can redistribute it and/or modify it under
+#                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
 
 package HiPi::Device::OneWire;
@@ -20,7 +16,7 @@ use Carp;
 use HiPi;
 use parent qw( HiPi::Device );
 
-our $VERSION = '0.21';
+our $VERSION ='0.61';
 
 our %idmap = (
     '01' => [ '2401/11', 'silicon serial number'], 
@@ -33,7 +29,7 @@ our %idmap = (
     '0A' => [ '', '16k memory ibutton'], 
     '0B' => [ '2505', '16k add-only memory'], 
     '0C' => [ '', '64k memory ibutton'], 
-    '0F' => [ '2506', '64k add-only memory'], 
+    '0F' => [ '2506', '64k add-only  memory'], 
     '10' => [ '18S20', 'high precision digital thermometer'], 
     '12' => [ '2406/2407', 'dual addressable switch plus 1k memory'], 
     '14' => [ '2430A', '256 eeprom'], 
@@ -70,20 +66,17 @@ our %idmap = (
     'FF' => [ 'LCD', 'LCD (Swart)'], 
 );
 
-our @_moduleinfo = (
-    { name => 'wire',     params => {}, },
-    { name => 'w1_gpio',  params => {}, },
-    { name => 'w1_therm', params => {}, },
-);
-
-sub get_module_info {
-    return @_moduleinfo;
+sub get_required_module_options {
+    my $moduleoptions = [
+        [ qw( w1_gpio wire ) ], # w1_therm is loaded on demand
+    ];
+    return $moduleoptions;
 }
 
 sub list_slaves {
     my( $class ) = @_;
     my @rlist = ();
-    my $slist = HiPi::qx_sudo_shell('/bin/cat /sys/bus/w1/devices/w1_bus_master1/w1_master_slaves 2>&1');
+    my $slist = qx(/bin/cat /sys/bus/w1/devices/w1_bus_master1/w1_master_slaves);
     if( $? ) {
         return @rlist;
     }
@@ -104,15 +97,15 @@ sub list_slaves {
 sub read_data {
     my( $class, $id ) = @_;
     # return data & or errors
-    my $data = HiPi::qx_sudo_shell(qq(/bin/cat /sys/bus/w1/devices/$id/w1_slave 2>&1));
+    my $data = qx(/bin/cat /sys/bus/w1/devices/$id/w1_slave);
     chomp($data);
     return $data;
 }
 
 sub id_exists {
     my( $class, $id) = @_;
-    my $slist = HiPi::qx_sudo_shell('/bin/cat /sys/bus/w1/devices/w1_bus_master1/w1_master_slaves 2>&1');
+    my $slist = qx(/bin/cat /sys/bus/w1/devices/w1_bus_master1/w1_master_slaves);
     return ( $slist =~ /\Q$id\E/ && -e qq(/sys/bus/w1/devices/$id/w1_slave) ) ? 1 : 0;
 }
 
-1;
+1;
\ No newline at end of file
