@@ -1,13 +1,9 @@
 #########################################################################################
-# Package       HiPi::Device::SerialPort
-# Description:  Serial Port driver
-# Created       Sat Nov 24 19:29:33 2012
-# SVN Id        $Id: SerialPort.pm 3 2015-03-12 01:07:32Z Mark Dootson $
-# Copyright:    Copyright (c) 2012 Mark Dootson
-# Licence:      This work is free software; you can redistribute it and/or modify it 
-#               under the terms of the GNU General Public License as published by the 
-#               Free Software Foundation; either version 3 of the License, or any later 
-#               version.
+# Package        HiPi::Device::SerialPort
+# Description:   Serial Port driver
+# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# License      : This is free software; you can redistribute it and/or modify it under
+#                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
 
 package HiPi::Device::SerialPort;
@@ -19,9 +15,9 @@ use warnings;
 use parent qw( HiPi::Device );
 use Carp;
 use Try::Tiny;
-require Device::SerialPort;
+require Device::SerialPort if $^O =~ /^linux$/i;
 
-our $VERSION = '0.22';
+our $VERSION ='0.61';
 
 __PACKAGE__->create_accessors( qw( portopen baudrate parity stopbits databits serialdriver ) );
 
@@ -91,9 +87,6 @@ sub can_read {
 sub read {
     my($self, $timeout) = @_;
     $timeout ||= 0;
-    
-    
-    
 }
 
 sub close {
