@@ -1,13 +1,9 @@
 #########################################################################################
-# Package       HiPi::Interface::DS18X20
-# Description:  1 Wire Thermometers 
-# Created       Sun Feb 10 03:05:26 2013
-# SVN Id        $Id: DS18X20.pm 3 2015-03-12 01:07:32Z Mark Dootson $
-# Copyright:    Copyright (c) 2013 Mark Dootson
-# Licence:      This work is free software; you can redistribute it and/or modify it 
-#               under the terms of the GNU General Public License as published by the 
-#               Free Software Foundation; either version 3 of the License, or any later 
-#               version.
+# Package        HiPi::Interface::DS18X20
+# Description  : 1 Wire Thermometers 
+# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# License      : This is free software; you can redistribute it and/or modify it under
+#                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
 
 package HiPi::Interface::DS18X20;
@@ -20,7 +16,7 @@ use parent qw( HiPi::Interface );
 use HiPi::Device::OneWire;
 use Carp;
 
-our $VERSION = '0.22';
+our $VERSION ='0.61';
 
 __PACKAGE__->create_accessors( qw( id correction divider) );
 
@@ -57,3 +53,5 @@ sub temperature {
 }
 
 1;
+
+__END__
\ No newline at end of file
