@@ -1,13 +1,9 @@
 #########################################################################################
-# Package       HiPi::Interface::MCP23017
-# Description:  Control MCP23017 Port Extender via I2C
-# Created       Sun Dec 02 01:42:27 2012
-# SVN Id        $Id: MCP23017.pm 77 2016-03-29 13:37:05Z Mark Dootson $
-# Copyright:    Copyright (c) 2012-2016 Mark Dootson
-# Licence:      This work is free software; you can redistribute it and/or modify it 
-#               under the terms of the GNU General Public License as published by the 
-#               Free Software Foundation; either version 3 of the License, or any later 
-#               version.
+# Package        HiPi::Interface::MCP23017
+# Description:   Control MCP23017 Port Extender via I2C
+# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# License      : This is free software; you can redistribute it and/or modify it under
+#                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
 
 package HiPi::Interface::MCP23017;
@@ -16,44 +12,54 @@ package HiPi::Interface::MCP23017;
 
 use strict;
 use warnings;
-use parent qw( HiPi::Interface::MCP23X17 );
-use HiPi::Constant qw( :raspberry );
+use parent qw( HiPi::Interface::Common::MCP23X17 );
+use HiPi qw( :rpi :mcp23x17 );
+use HiPi::RaspberryPi;
 use Carp;
 
-our $VERSION = '0.25';
+our $VERSION ='0.61';
+
+# compatibility
 
 our @EXPORT = ();
 our @EXPORT_OK = ();
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-use constant $HiPi::Interface::MCP23X17::mcp23S17const;
-use constant $HiPi::Interface::MCP23X17::mcp23017const;
-use constant $HiPi::Interface::MCP23X17::mcpPinConst;
-
+# legacy compat exports
 {
-    # allow use of constants with both naming conventions
-    my @const23S17 = ( keys %$HiPi::Interface::MCP23X17::mcp23S17const );
-    push( @EXPORT_OK, @const23S17 );
-    $EXPORT_TAGS{mcp23S17} = \@const23S17;
+    my @const = qw(
+        MCP23S17_A0 MCP23S17_A1 MCP23S17_A2 MCP23S17_A3 MCP23S17_A4 MCP23S17_A5 MCP23S17_A6 MCP23S17_A7 
+        MCP23S17_B0 MCP23S17_B1 MCP23S17_B2 MCP23S17_B3 MCP23S17_B4 MCP23S17_B5 MCP23S17_B6 MCP23S17_B7
+        MCP23S17_BANK MCP23S17_MIRROR MCP23S17_SEQOP MCP23S17_DISSLW MCP23S17_HAEN MCP23S17_ODR MCP23S17_INTPOL
+        MCP23S17_INPUT MCP23S17_OUTPUT MCP23S17_HIGH MCP23S17_LOW
+        
+        MCP23017_A0 MCP23017_A1 MCP23017_A2 MCP23017_A3 MCP23017_A4 MCP23017_A5 MCP23017_A6 MCP23017_A7 
+        MCP23017_B0 MCP23017_B1 MCP23017_B2 MCP23017_B3 MCP23017_B4 MCP23017_B5 MCP23017_B6 MCP23017_B7
+        MCP23017_BANK MCP23017_MIRROR MCP23017_SEQOP MCP23017_DISSLW MCP23017_HAEN MCP23017_ODR MCP23017_INTPOL
+        MCP23017_INPUT MCP23017_OUTPUT MCP23017_HIGH MCP23017_LOW
+    );
     
-    my @const23017 = ( keys %$HiPi::Interface::MCP23X17::mcp23017const );
-    push( @EXPORT_OK, @const23017 );
-    $EXPORT_TAGS{mcp23017} = \@const23017;
+    my @constpins = qw(
+        MCP_PIN_A0 MCP_PIN_A1 MCP_PIN_A2 MCP_PIN_A3 MCP_PIN_A4 MCP_PIN_A5 MCP_PIN_A6 MCP_PIN_A7
+        MCP_PIN_B0 MCP_PIN_B1 MCP_PIN_B2 MCP_PIN_B3 MCP_PIN_B4 MCP_PIN_B5 MCP_PIN_B6 MCP_PIN_B7
+    );
     
-    my @constMCPpin = ( keys %$HiPi::Interface::MCP23X17::mcpPinConst );
-    push( @EXPORT_OK, @constMCPpin );
-    $EXPORT_TAGS{mcppin} = \@constMCPpin;
+    push( @EXPORT_OK, @const, @constpins );
+    $EXPORT_TAGS{mcp23017} = \@const;
+    $EXPORT_TAGS{mcp23S17} = \@const;
+    $EXPORT_TAGS{mcppin} = \@constpins;
 }
 
 sub new {
     my ($class, %userparams) = @_;
     
+    my $pi = HiPi::RaspberryPi->new();
+    
     my %params = (
-        devicename  => ( RPI_BOARD_REVISION == 1 ) ? '/dev/i2c-0' : '/dev/i2c-1',
+        devicename   => ( $pi->board_type == RPI_BOARD_TYPE_1 ) ? '/dev/i2c-0' : '/dev/i2c-1',
         address     => 0x20,
         device      => undef,
         backend     => 'smbus',
-     _function_mode => 'hipi',
     );
     
     # get user params
@@ -62,13 +68,11 @@ sub new {
     }
     
     unless( defined($params{device}) ) {
-        
         if ( $params{backend} eq 'bcm2835' ) {
             require HiPi::BCM2835::I2C;
             $params{device} = HiPi::BCM2835::I2C->new(
                 address    => $params{address},
                 peripheral => ( $params{devicename} eq '/dev/i2c-0' ) ? HiPi::BCM2835::I2C::BB_I2C_PERI_0() : HiPi::BCM2835::I2C::BB_I2C_PERI_1(),
-            _function_mode => $params{_function_mode},
             );
         } else {
             require HiPi::Device::I2C;
@@ -83,7 +87,6 @@ sub new {
     my $self = $class->SUPER::new(%params);
     
     # get current register address config so correct settings are loaded
-    
     $self->read_register_bytes('IOCON');
     
     return $self;
