@@ -1,13 +1,9 @@
 #########################################################################################
-# Package       HiPi::Interface::MCP23S17
-# Description:  Control MCP23S17 Port Extender via SPI
-# Created       Sun Dec 02 01:42:27 2012
-# SVN Id        $Id: MCP23S17.pm 3 2015-03-12 01:07:32Z Mark Dootson $
-# Copyright:    Copyright (c) 2016 Mark Dootson
-# Licence:      This work is free software; you can redistribute it and/or modify it 
-#               under the terms of the GNU General Public License as published by the 
-#               Free Software Foundation; either version 3 of the License, or any later 
-#               version.
+# Package        HiPi::Interface::MCP23S17
+# Description  : Control MCP23S17 Port Extender via SPI
+# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# License      : This is free software; you can redistribute it and/or modify it under
+#                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
 
 package HiPi::Interface::MCP23S17;
@@ -16,39 +12,47 @@ package HiPi::Interface::MCP23S17;
 
 use strict;
 use warnings;
-use parent qw( HiPi::Interface::MCP23X17 );
-use HiPi::Constant qw( :raspberry );
+use parent qw( HiPi::Interface::Common::MCP23X17 );
+use HiPi qw( :rpi :spi :mcp23S17 );
+use HiPi::Device::SPI;
 use Carp;
-use HiPi::Device::SPI qw( :spi );
 
-our $VERSION = '0.25';
+our $VERSION ='0.61';
+
+# compatibility
 
 our @EXPORT = ();
 our @EXPORT_OK = ();
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-use constant $HiPi::Interface::MCP23X17::mcp23S17const;
-use constant $HiPi::Interface::MCP23X17::mcp23017const;
-use constant $HiPi::Interface::MCP23X17::mcpPinConst;
-
+# legacy compat exports
 {
-    # allow use of constants with both naming conventions
-    my @const23S17 = ( keys %$HiPi::Interface::MCP23X17::mcp23S17const );
-    push( @EXPORT_OK, @const23S17 );
-    $EXPORT_TAGS{mcp23S17} = \@const23S17;
+    my @const = qw(
+        MCP23S17_A0 MCP23S17_A1 MCP23S17_A2 MCP23S17_A3 MCP23S17_A4 MCP23S17_A5 MCP23S17_A6 MCP23S17_A7 
+        MCP23S17_B0 MCP23S17_B1 MCP23S17_B2 MCP23S17_B3 MCP23S17_B4 MCP23S17_B5 MCP23S17_B6 MCP23S17_B7
+        MCP23S17_BANK MCP23S17_MIRROR MCP23S17_SEQOP MCP23S17_DISSLW MCP23S17_HAEN MCP23S17_ODR MCP23S17_INTPOL
+        MCP23S17_INPUT MCP23S17_OUTPUT MCP23S17_HIGH MCP23S17_LOW
+        
+        MCP23017_A0 MCP23017_A1 MCP23017_A2 MCP23017_A3 MCP23017_A4 MCP23017_A5 MCP23017_A6 MCP23017_A7 
+        MCP23017_B0 MCP23017_B1 MCP23017_B2 MCP23017_B3 MCP23017_B4 MCP23017_B5 MCP23017_B6 MCP23017_B7
+        MCP23017_BANK MCP23017_MIRROR MCP23017_SEQOP MCP23017_DISSLW MCP23017_HAEN MCP23017_ODR MCP23017_INTPOL
+        MCP23017_INPUT MCP23017_OUTPUT MCP23017_HIGH MCP23017_LOW
+    );
     
-    my @const23017 = ( keys %$HiPi::Interface::MCP23X17::mcp23017const );
-    push( @EXPORT_OK, @const23017 );
-    $EXPORT_TAGS{mcp23017} = \@const23017;
+    my @constpins = qw(
+        MCP_PIN_A0 MCP_PIN_A1 MCP_PIN_A2 MCP_PIN_A3 MCP_PIN_A4 MCP_PIN_A5 MCP_PIN_A6 MCP_PIN_A7
+        MCP_PIN_B0 MCP_PIN_B1 MCP_PIN_B2 MCP_PIN_B3 MCP_PIN_B4 MCP_PIN_B5 MCP_PIN_B6 MCP_PIN_B7
+    );
     
-    my @constMCPpin = ( keys %$HiPi::Interface::MCP23X17::mcpPinConst );
-    push( @EXPORT_OK, @constMCPpin );
-    $EXPORT_TAGS{mcppin} = \@constMCPpin;
+    push( @EXPORT_OK, @const, @constpins );
+    $EXPORT_TAGS{mcp23017} = \@const;
+    $EXPORT_TAGS{mcp23S17} = \@const;
+    $EXPORT_TAGS{mcppin} = \@constpins;
 }
 
 use constant {
-    SPI_READ        => 0x41,
-    SPI_WRITE       => 0x40,
+    MCP_SPI_READ_MASK   => 0x41,
+    MCP_SPI_WRITE_MASK  => 0x40,
 };
 
 sub new {
@@ -87,7 +91,7 @@ sub new {
 
 sub do_write_register_bytes {
     my($self, $regaddress, @bytes) = @_;
-    my $devaddr = SPI_WRITE + ( $self->address << 1 );
+    my $devaddr = MCP_SPI_WRITE_MASK + ( $self->address << 1 );
     $self->device->transfer( pack('C*', ( $devaddr, $regaddress, @bytes ) ) );
     return 1;
 }
@@ -97,7 +101,7 @@ sub do_read_register_bytes {
     my @bufferbytes = ( (1) x $numbytes );
     my $packbytes = $numbytes + 2;
     my $format = 'C' . $packbytes;
-    my $devaddr = SPI_READ + ( $self->address << 1 );
+    my $devaddr = MCP_SPI_READ_MASK + ( $self->address << 1 );
     my @vals = unpack($format, $self->device->transfer( pack($format, ( $devaddr, $regaddress, @bufferbytes )) ));
     # first 2 vals in return buffer are not part of returned data
     shift @vals; shift @vals;
