@@ -1,13 +1,9 @@
 #########################################################################################
-# Package       HiPi::Interface::SerLCD
-# Description:  SerLCD RX Enabled LCD Controller
-# Created       Sat Nov 24 20:48:42 2012
-# SVN Id        $Id: SerLCD.pm 22 2016-03-04 21:38:30Z Mark Dootson $
-# Copyright:    Copyright (c) 2012 Mark Dootson
-# Licence:      This work is free software; you can redistribute it and/or modify it 
-#               under the terms of the GNU General Public License as published by the 
-#               Free Software Foundation; either version 3 of the License, or any later 
-#               version.
+# Package        HiPi::Interface::SerLCD
+# Description  : SerLCD RX Enabled LCD Controller
+# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# License      : This is free software; you can redistribute it and/or modify it under
+#                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
 
 package HiPi::Interface::SerLCD;
@@ -16,16 +12,11 @@ package HiPi::Interface::SerLCD;
 
 use strict;
 use warnings;
-use parent qw( HiPi::Interface::HD44780 );
-use feature qw( switch );
+use parent qw( HiPi::Interface::Common::HD44780 );
 use Carp;
+use HiPi qw( :lcd );
 
-our $VERSION = '0.20';
-
-use constant {
-    SLCD_START_COMMAND    => chr(0xFE),
-    SLCD_SPECIAL_COMMAND  => chr(0x7C),
-};
+our $VERSION ='0.61';
 
 sub new {
     my ($class, %userparams) = @_;
