@@ -1,26 +1,21 @@
 #########################################################################################
 # Package       HiPi::Pin
 # Description:  GPIO / Extender Pin
-# Created       Wed Feb 20 04:39:18 2013
-# SVN Id        $Id: Pin.pm 22 2016-03-04 21:38:30Z Mark Dootson $
-# Copyright:    Copyright (c) 2013 Mark Dootson
-# Licence:      This work is free software; you can redistribute it and/or modify it 
-#               under the terms of the GNU General Public License as published by the 
-#               Free Software Foundation; either version 3 of the License, or any later 
-#               version.
+# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# License      : This is free software; you can redistribute it and/or modify it under
+#                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
 
 package HiPi::Pin;
 
 #########################################################################################
-use 5.14.0;
+
 use strict;
 use warnings;
-use HiPi::Class;
-use base qw( HiPi::Class );
-use HiPi::Constant qw( :raspberry );
+use parent qw( HiPi::Class );
+use HiPi qw( :rpi );
 
-our $VERSION = '0.32';
+our $VERSION ='0.61';
 
 __PACKAGE__->create_ro_accessors( qw( pinid ) );
 
