@@ -1,13 +1,9 @@
 #########################################################################################
-# Package       HiPi::Utils::Exec
-# Description:  Executable Wrappers
-# Created       Tue Mar 19 03:01:17 2013
-# SVN Id        $Id: Exec.pm 98 2016-04-06 04:32:02Z Mark Dootson $
-# Copyright:    Copyright (c) 2013-2015 Mark Dootson
-# Licence:      This work is free software; you can redistribute it and/or modify it 
-#               under the terms of the GNU General Public License as published by the 
-#               Free Software Foundation; either version 3 of the License, or any later 
-#               version.
+# Package        HiPi::Utils::Exec
+# Description  : Executable Wrappers
+# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# License      : This is free software; you can redistribute it and/or modify it under
+#                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
 
 package HiPi::Utils::Exec;
@@ -23,14 +19,13 @@ use Carp;
 use File::Slurp;
 use Cwd;
 use Try::Tiny;
-
-use HiPi::Utils qw( is_raspberry );
+use HiPi;
 
 __PACKAGE__->create_accessors( qw( workingdir sourceperl outputexec ) );
 
-our $VERSION ='0.50';
+our $VERSION ='0.61';
 
-XSLoader::load 'HiPi::Utils::Exec', $VERSION if is_raspberry;
+XSLoader::load('HiPi::Utils::Exec', $VERSION) if HiPi::is_raspberry_pi();
 
 sub new {
     my ($class, %params) = @_;
@@ -132,7 +127,7 @@ sub decompress_buffer {
 
 sub makefile_template {
     my $self = shift;
-    my $template = <<'HIPIMAKEFILETEMPLATE'
+    my $template = <<'PEPIMAKEFILETEMPLATE'
 
 MV=mv -f
 RM=rm -f
@@ -168,7 +163,7 @@ exec: $(OBJECTS)
 	-$(LD) $(LDFLAGS) $(OBJECTS) $(LDLIBS) -o REPLACEOBJNAME
 	strip REPLACEOBJNAME
 
-HIPIMAKEFILETEMPLATE
+PEPIMAKEFILETEMPLATE
 ;
     my $perl = $^X;
     $template =~ s/REPLACEPERL/$perl/g;
@@ -200,11 +195,10 @@ HIPIMAKEFILETEMPLATE
 
 sub main_template {
     my $self = shift;
-    my $template = <<'HIPIMAINTEMPLATE'
+    my $template = <<'PEPIMAINTEMPLATE'
 #include <EXTERN.h>
 #include <perl.h>
 #include <XSUB.h>
-#include "../mylib/include/ppport.h"
 #include <zlib.h>
 
 extern char **environ;
@@ -405,12 +399,10 @@ int main ( int argc, char **argv )
     return exitstatus;
 }
 
-HIPIMAINTEMPLATE
+PEPIMAINTEMPLATE
 ;
     
     return $template;
 }
 
-
-
 1;
